@@ -155,18 +155,18 @@ else:
         return b
 
 
-LF = ntob('\n')
-CRLF = ntob('\r\n')
-TAB = ntob('\t')
-SPACE = ntob(' ')
-COLON = ntob(':')
-SEMICOLON = ntob(';')
-EMPTY = ntob('')
-NUMBER_SIGN = ntob('#')
-QUESTION_MARK = ntob('?')
-ASTERISK = ntob('*')
-FORWARD_SLASH = ntob('/')
-quoted_slash = re.compile(ntob('(?i)%2F'))
+LF = b'\n'
+CRLF = b'\r\n'
+TAB = b'\t'
+SPACE = b' '
+COLON = b':'
+SEMICOLON = b';'
+EMPTY = b''
+NUMBER_SIGN = b'#'
+QUESTION_MARK = b'?'
+ASTERISK = b'*'
+FORWARD_SLASH = b'/'
+quoted_slash = re.compile(b'(?i)%2F')
 
 
 def plat_specific_errors(*errnames):
@@ -579,9 +579,9 @@ class HTTPRequest(object):
 
         self.ready = False
         self.started_request = False
-        self.scheme = ntob('http')
+        self.scheme = b'http'
         if self.server.ssl_adapter is not None:
-            self.scheme = ntob('https')
+            self.scheme = b'https'
         # Use the lowest-common protocol in case read_request_line errors.
         self.response_protocol = 'HTTP/1.0'
         self.inheaders = {}
@@ -1695,7 +1695,7 @@ class ThreadPool(object):
 
         # Don't join currentThread (when stop is called inside a request).
         current = threading.currentThread()
-        if timeout and timeout >= 0:
+        if timeout is not None and timeout >= 0:
             endtime = time.time() + timeout
         while self._threads:
             worker = self._threads.pop()
@@ -2052,11 +2052,13 @@ class HTTPServer(object):
         if self.ssl_adapter is not None:
             self.socket = self.ssl_adapter.bind(self.socket)
 
+        host, port = self.bind_addr[:2]
+
         # If listening on the IPV6 any address ('::' = IN6ADDR_ANY),
         # activate dual-stack. See
         # https://github.com/cherrypy/cherrypy/issues/871.
         if (hasattr(socket, 'AF_INET6') and family == socket.AF_INET6
-                and self.bind_addr[0] in ('::', '::0', '::0.0.0.0')):
+                and host in ('::', '::0', '::0.0.0.0')):
             try:
                 self.socket.setsockopt(
                     socket.IPPROTO_IPV6, socket.IPV6_V6ONLY, 0)
@@ -2097,7 +2099,7 @@ class HTTPServer(object):
                     sock_to_make = s if six.PY3 else s._sock
                     wfile = makefile(sock_to_make, 'wb', DEFAULT_BUFFER_SIZE)
                     try:
-                        wfile.write(ntob(''.join(buf)))
+                        wfile.write(''.join(buf).encode('ISO-8859-1'))
                     except socket.error:
                         x = sys.exc_info()[1]
                         if x.args[0] not in socket_errors_to_ignore:
